@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package JSON::Schema::Modern; # git description: v0.531-10-gd8abacc6
+package JSON::Schema::Modern; # git description: v0.532-7-ga7669dcf
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Validate data against a schema
 # KEYWORDS: JSON Schema data validation structure specification
 
-our $VERSION = '0.532';
+our $VERSION = '0.533';
 
 use 5.020;  # for fc, unicode_strings features
 use Moo;
@@ -922,7 +922,7 @@ JSON::Schema::Modern - Validate data against a schema
 
 =head1 VERSION
 
-version 0.532
+version 0.533
 
 =head1 SYNOPSIS
 
@@ -1496,6 +1496,13 @@ L<Understanding JSON Schema|https://json-schema.org/understanding-json-schema>:
 
 =head1 SUPPORT
 
+=for stopwords OpenAPI
+
+You can also find me on the L<JSON Schema Slack server|https://json-schema.slack.com> and L<OpenAPI Slack
+server|https://open-api.slack.com>, which are also great resources for finding help.
+
+=head1 SUPPORT
+
 Bugs may be submitted through L<https://github.com/karenetheridge/JSON-Schema-Modern/issues>.
 
 I am also usually active on irc, as 'ether' at C<irc.perl.org> and C<irc.libera.chat>.
