@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Vocabulary::Content;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Implementation of the JSON Schema Content vocabulary
 
-our $VERSION = '0.532';
+our $VERSION = '0.533';
 
 use 5.020;
 use Moo;
@@ -111,7 +111,7 @@ JSON::Schema::Modern::Vocabulary::Content - Implementation of the JSON Schema Co
 
 =head1 VERSION
 
-version 0.532
+version 0.533
 
 =head1 DESCRIPTION
 
@@ -145,6 +145,13 @@ L<JSON::Schema::Modern/add_encoding> and L<JSON::Schema::Modern/add_media_type>.
 
 =head1 SUPPORT
 
+=for stopwords OpenAPI
+
+You can also find me on the L<JSON Schema Slack server|https://json-schema.slack.com> and L<OpenAPI Slack
+server|https://open-api.slack.com>, which are also great resources for finding help.
+
+=head1 SUPPORT
+
 Bugs may be submitted through L<https://github.com/karenetheridge/JSON-Schema-Modern/issues>.
 
 I am also usually active on irc, as 'ether' at C<irc.perl.org> and C<irc.libera.chat>.
